@@ -16,7 +16,7 @@ class TableViewAction(Action):
     if admin:
       self.admin = admin(self.parent_admin, entity)
     else:
-      self.admin = self.parent_admin.getEntityAdmin(entity)
+      self.admin = self.parent_admin.get_entity_admin(entity)
     self.entity = entity
     self.verbose_name = verbose_name
   
@@ -24,7 +24,7 @@ class TableViewAction(Action):
     return self.verbose_name or self.admin.get_verbose_name_plural()
     
   def run(self, parent):
-    tableview = self.admin.createTableView(parent)
+    tableview = self.admin.create_table_view(parent)
     return tableview
     
 def structure_to_action(structure):
