@@ -61,7 +61,28 @@ a list with the fields that should be displayed in a table view
 .. attribute:: form_display 
 
 a list with the fields that should be displayed in a form view, defaults to the same
-fields as those specified in list_display
+fields as those specified in list_display ::
+
+  class Admin(EntityAdmin):
+    form_display = ['title', 'rating', 'cover']
+    
+instead of telling which forms to display. It is also possible to define the form itself ::
+
+  from camelot.view.forms import Form, TabForm, WidgetOnlyForm, HBoxForm
+
+  class Admin(EntityAdmin):
+    form_display = TabForm([
+      ('Movie', Form([
+        HBoxForm([['title', 'rating'], WidgetOnlyForm('cover')]),
+        'short_description',
+        'releasedate', 
+        'director',
+        'script', 
+        'genre', 
+        'description', 'tags'], scrollbars=True)),
+      ('Cast', WidgetOnlyForm('cast'))
+    ])
+
 
 .. attribute:: list_filter
 
@@ -76,6 +97,8 @@ field name of the related entity ::
     class Admin(EntityAdmin):
       list_display = ['organization']
       list_filter = ['organization.name']
+      
+.. image:: ../_static/filter/group_box_filter.png
 
 .. attribute:: list_search
 
@@ -183,10 +206,19 @@ Other field attributes process by the admin interface are:
     
   def getModelThread(self):
     return self.mt
+  
+  def getEntityAdmin(self, entity):
+    return self.app_admin.getEntityAdmin(entity)
 
   @model_function
-  def getFormActions(self, entity):
-    return self.form_actions
+  def get_form_actions(self, entity):
+    from camelot.admin.form_action import structure_to_form_actions
+    return structure_to_form_actions(self.form_actions)
+  
+  @model_function
+  def get_list_actions(self):
+    from camelot.admin.list_action import structure_to_list_actions
+    return structure_to_list_actions(self.list_actions)
   
   def getRelatedEntityAdmin(self, entity):
     """
@@ -195,7 +227,7 @@ Other field attributes process by the admin interface are:
     application admin object.
     @param entity: the entity class for which an admin object is requested 
     """
-    related_admin = self.app_admin.getEntityAdmin(entity)
+    related_admin = self.app_admin.get_entity_admin(entity)
     if not related_admin:
       logger.warn('no related admin found for %s'%(entity.__name__))
     return related_admin
@@ -221,12 +253,13 @@ Other field attributes process by the admin interface are:
       #
       attributes = dict(python_type=str,
                         length=None,
+                        tooltip=None,
                         minimal_column_width=0,
                         editable=False,
                         nullable=True,
                         widget='str',
                         blank=True,
-                        delegate=delegates.PlainTextColumnDelegate,
+                        delegate=delegates.PlainTextDelegate,
                         validator_list=[],
                         name=field_name.replace('_', ' ').capitalize())
       
@@ -309,7 +342,7 @@ Other field attributes process by the admin interface are:
     return Form([f for f, a in self.getFields()])
   
   @gui_function
-  def createFormView(self, title, model, index, parent):
+  def create_form_view(self, title, model, index, parent):
     """Creates a Qt widget containing a form view, for a specific index in a
     model; uses the Admin class
     """
