@@ -36,15 +36,19 @@ import camelot
 import camelot.types
 
 from camelot.model import *
-from camelot.model.synchronization import *
 
 __metadata__ = metadata
 
+from camelot.model.synchronization import *
+from camelot.core.document import documented_entity
+
 from camelot.view.elixir_admin import EntityAdmin
 from camelot.view.forms import Form, TabForm, VBoxForm, HBoxForm, WidgetOnlyForm
+from camelot.admin.form_action import FormActionFromModelFunction
 import datetime
+import threading
 
-_current_authentication_ = None
+_current_authentication_ = threading.local()
 
 def end_of_times():
   return datetime.date(year=2400, month=12, day=31)
@@ -52,10 +56,10 @@ def end_of_times():
 def getCurrentAuthentication():
   """Get the currently logged in person"""
   global _current_authentication_
-  if not _current_authentication_:
+  if not hasattr(_current_authentication_, 'mechanism'):
     import getpass
-    _current_authentication_ = UsernameAuthenticationMechanism.getOrCreateAuthentication(unicode(getpass.getuser()))
-  return _current_authentication_
+    _current_authentication_.mechanism = UsernameAuthenticationMechanism.getOrCreateAuthentication(unicode(getpass.getuser()))
+  return _current_authentication_.mechanism
 
 def updateLastLogin():
   """Update the last login of the current person to now"""
@@ -90,8 +94,8 @@ class EmployerEmployee(PartyRelationship):
     return sql.select([Person.last_name], Person.c.party_id==self.established_to_party_id)
   
   @ColumnProperty
-  def passport_number(self):
-    return sql.select([Person.passport_number], Person.c.party_id==self.established_to_party_id)
+  def social_security_number(self):
+    return sql.select([Person.social_security_number], Person.c.party_id==self.established_to_party_id)
   
   def __unicode__(self):
     return u'%s employed by %s'%(unicode(self.established_to), unicode(self.established_from))
@@ -207,6 +211,10 @@ class Party(Entity):
   shares = OneToMany('SharedShareholder', inverse='established_to')
   directed_organizations = OneToMany('DirectedDirector', inverse='established_to')
     
+  @property
+  def name(self):
+    return ''
+  
   @ColumnProperty
   def full_name(c):
     aliased_organisation = Organization.table.alias('organisation_alias')
@@ -268,6 +276,8 @@ class Organization(Party):
                             ('Suppliers', Form(['suppliers'])),
                             ('Corporate', Form(['directors', 'shareholders', 'shares'])),
                             ('Branding', Form(['logo'])), ])
+    
+Organization = documented_entity()(Organization)       
 
 class AuthenticationMechanism(Entity):
   using_options(tablename='authentication_mechanism')
@@ -276,6 +286,7 @@ class AuthenticationMechanism(Entity):
   
   class Admin(EntityAdmin):
     verbose_name = 'Authentication mechanism'
+    list_display = ['last_login', 'is_active']
   
 class UsernameAuthenticationMechanism(AuthenticationMechanism):
   using_options(tablename='authentication_mechanism_username', inheritance='multi')
@@ -297,14 +308,9 @@ class UsernameAuthenticationMechanism(AuthenticationMechanism):
   class Admin(EntityAdmin):
     verbose_name = 'Authentication mechanism'
     list_display = ['username', 'last_login', 'is_active']
-  
+      
 class Person(Party):
-  """Person represents natural persons, these can be given access to the system
-  and as such require a username.
-  
-  Username is required, other fields are optional, there is no password because
-  authentication is supposed to happen through the operating system services or
-  other.
+  """Person represents natural persons
   """
   using_options(tablename='person', inheritance='multi')
   first_name = Field(Unicode(40), required=True)
@@ -346,6 +352,8 @@ class Person(Party):
                             ('Work', Form(['employers', 'directed_organizations', 'shares'], scrollbars=True))
                             ])
     
+Person = documented_entity()(Person)   
+
 class GeographicBoundary(Entity):
   using_options(tablename='geographic_boundary')
   code = Field(Unicode(10))
@@ -417,12 +425,13 @@ class Address(Entity):
   class Admin(EntityAdmin):
     verbose_name = 'Address'
     verbose_name_plural = 'Addresses'
-    section = 'relations'
     list_display = ['street1', 'street2', 'city']
     form_size = (700,150)
-    field_attributes = {'street1':{'minimal_column_width':100}}
-    form_actions = [('Show map',lambda address:address.showMap())]
+    field_attributes = {'street1':{'minimal_column_width':30}}
+    form_actions = [FormActionFromModelFunction('Show on map', lambda address:address.showMap())]
   
+Address = documented_entity()(Address) 
+
 class PartyAddressRoleType(Entity):
   using_options(tablename='party_address_role_type')
   code = Field(Unicode(10))
@@ -460,7 +469,7 @@ class PartyAddress(Entity):
     list_display = ['address', 'comment']
     fields = ['address', 'comment', 'from_date', 'thru_date']
     form_size = (700,200)
-    form_actions = [('Show map',lambda address:address.showMap())]
+    form_actions = [FormActionFromModelFunction('Show on map', lambda address:address.showMap())]
     
 class ContactMechanism(Entity):
   using_options(tablename='contact_mechanism')
@@ -474,10 +483,11 @@ class ContactMechanism(Entity):
   class Admin(EntityAdmin):
     form_size = (700,150)
     verbose_name = 'Contact mechanism'
-    section = 'relations'
     list_display = ['mechanism']
     form_display = Form(['mechanism', 'party_address'])
-    field_attributes = {'mechanism':{'minimal_column_width':120}}
+    field_attributes = {'mechanism':{'minimal_column_width':25}}
+
+ContactMechanism = documented_entity()(ContactMechanism) 
 
 class PartyContactMechanism(Entity):
   using_options(tablename='party_contact_mechanism')
