@@ -19,7 +19,7 @@ def open_html_in_outlook(html):
     return
   
   msg = outlook_app.CreateItem(0)
-  msg.BodyFormat=2
+  #msg.BodyFormat=2
   msg.HTMLBody=html
   #msg.Subject=o_subject
   msg.Display(True)
