@@ -5,9 +5,10 @@
 
 import camelot.types
 from camelot.model import metadata, Entity, Field, ManyToOne, OneToMany, ManyToMany, \
-                          Unicode, Date, Integer, using_options
+                          Unicode, Date, Integer, Boolean, using_options
 from camelot.view.elixir_admin import EntityAdmin
 from camelot.view.forms import Form, TabForm, WidgetOnlyForm, HBoxForm
+from camelot.view.controls import delegates
 
 __metadata__ = metadata
 
@@ -63,7 +64,7 @@ class Movie(Entity):
   class Admin(EntityAdmin):
     # the list_display attribute specifies which entity attributes should
     # be visible in the table view        
-    list_display = ['title', 'releasedate', 'director',]
+    list_display = ['title', 'releasedate', 'director', 'description']
     # define filters to be available in the table view
     list_filter = ['genre']
     # the form_display attribute specifies which entity attributes should be
@@ -89,7 +90,15 @@ class Movie(Entity):
     # field_attributes dictionary
     #
     field_attributes = dict(cast=dict(create_inline=True),
-                            genre=dict(choices=genre_choices),)
+                            genre=dict(choices=genre_choices),
+                            rating=dict(tooltip=lambda o:'''<table>
+                                                              <tr><td>1 star</td><td>Not that good</td></tr>
+                                                              <tr><td>2 stars</td><td>Almost good</td></tr>
+                                                              <tr><td>3 stars</td><td>Good</td></tr>
+                                                              <tr><td>4 stars</td><td>Very good</td></tr>
+                                                              <tr><td>5 stars</td><td>Awesome !</td></tr>
+                                                            </table>'''),
+                            smiley=dict(delegate=delegates.SmileyDelegate))
 
   def __unicode__(self):
     return self.title or ''
